@@ -40,6 +40,7 @@ import java.util.Arrays;
 import java.util.Date;
 import java.util.HashMap;
 import java.util.HashSet;
+import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
@@ -76,6 +77,8 @@ public class FurnitureLibraryFileRecorder implements FurnitureLibraryRecorder {
   private static final String [] IGNORED_EXTENSIONS = {".max", ".lwo", ".dxf"};
   private static final Locale DEFAULT_LOCALE = new Locale("");
   
+  private static final String ID          = "id"; 
+  private static final String NAME        = "name"; 
   private static final String DESCRIPTION = "description"; 
   private static final String VERSION     = "version"; 
   private static final String LICENSE     = "license"; 
@@ -107,6 +110,8 @@ public class FurnitureLibraryFileRecorder implements FurnitureLibraryRecorder {
                                                                  URL furnitureCatalogUrl,
                                                                  URL furnitureResourcesUrlBase) {
             if (index == 1) {
+              furnitureLibrary.setId(getOptionalString(resource, ID));
+              furnitureLibrary.setName(getOptionalString(resource, NAME));
               furnitureLibrary.setDescription(getOptionalString(resource, DESCRIPTION));
               furnitureLibrary.setVersion(getOptionalString(resource, VERSION));
               furnitureLibrary.setLicense(getOptionalString(resource, LICENSE));
@@ -150,7 +155,7 @@ public class FurnitureLibraryFileRecorder implements FurnitureLibraryRecorder {
         furnitureLibrary.addPieceOfFurniture(piece);
       }
 
-      // Get furniture name and category name in each supported locale
+      // Get furniture name, description, information, tags and category name in each supported locale
       for (Locale locale : supportedLocales) {
         if (!FurnitureLibrary.DEFAULT_LANGUAGE.equals(locale.toString())) {          
           Locale.setDefault(locale);
@@ -169,6 +174,10 @@ public class FurnitureLibraryFileRecorder implements FurnitureLibraryRecorder {
                       FurnitureLibrary.FURNITURE_NAME_PROPERTY, piece.getName());
                   furnitureLibrary.setPieceOfFurnitureLocalizedData(furnitureLibraryPiece, language, 
                       FurnitureLibrary.FURNITURE_DESCRIPTION_PROPERTY, piece.getDescription());
+                  furnitureLibrary.setPieceOfFurnitureLocalizedData(furnitureLibraryPiece, language, 
+                      FurnitureLibrary.FURNITURE_INFORMATION_PROPERTY, piece.getInformation());
+                  furnitureLibrary.setPieceOfFurnitureLocalizedData(furnitureLibraryPiece, language, 
+                      FurnitureLibrary.FURNITURE_TAGS_PROPERTY, piece.getTags());
                   furnitureLibrary.setPieceOfFurnitureLocalizedData(furnitureLibraryPiece, language, 
                       FurnitureLibrary.FURNITURE_CATEGORY_PROPERTY, category.getName());
                 }
@@ -226,7 +235,7 @@ public class FurnitureLibraryFileRecorder implements FurnitureLibraryRecorder {
    *                       if <code>furnitureResourcesLocalDirectory</code> isn't <code>null</code>              
    */
   private void writeFurnitureLibrary(FurnitureLibrary furnitureLibrary,
-                                     String furnitureLibraryName,
+                                     String furnitureLibraryLocation,
                                      boolean offlineFurnitureLibrary,
                                      boolean contentMatchingFurnitureName,
                                      String  furnitureResourcesLocalDirectory,
@@ -252,7 +261,7 @@ public class FurnitureLibraryFileRecorder implements FurnitureLibraryRecorder {
     
     ZipOutputStream zipOut = null;
     Map<Content, String> contentEntries = new HashMap<Content, String>();
-    File furnitureLibraryFile = new File(furnitureLibraryName);
+    File furnitureLibraryFile = new File(furnitureLibraryLocation);
     File tmpFile = null;
     try {
       tmpFile = File.createTempFile("temp", ".sh3f"); 
@@ -286,13 +295,13 @@ public class FurnitureLibraryFileRecorder implements FurnitureLibraryRecorder {
         tmpFile.delete();
       }
     } catch (IOException ex) {
-      throw new RecorderException("Can't save furniture library file " + furnitureLibraryName, ex);
+      throw new RecorderException("Can't save furniture library file " + furnitureLibraryLocation, ex);
     } finally {
       if (zipOut != null) {
         try {
           zipOut.close();
         } catch (IOException ex) {
-          throw new RecorderException("Can't close furniture library file " + furnitureLibraryName, ex);
+          throw new RecorderException("Can't close furniture library file " + furnitureLibraryLocation, ex);
         }
       }
     }
@@ -321,6 +330,8 @@ public class FurnitureLibraryFileRecorder implements FurnitureLibraryRecorder {
         + "# Generated by Furniture Library Editor\n#\n";
     writer.write(String.format(CATALOG_FILE_HEADER, new Date()));
     writer.newLine();
+    writeProperty(writer, ID, furnitureLibrary.getId());
+    writeProperty(writer, NAME, furnitureLibrary.getName());
     writeProperty(writer, DESCRIPTION, furnitureLibrary.getDescription());
     writeProperty(writer, VERSION, furnitureLibrary.getVersion());
     writeProperty(writer, LICENSE, furnitureLibrary.getLicense());
@@ -548,23 +559,23 @@ public class FurnitureLibraryFileRecorder implements FurnitureLibraryRecorder {
         + DefaultFurnitureCatalog.PLUGIN_FURNITURE_CATALOG_FAMILY + "_" + language + ".properties %tc\n" 
         + "# Generated by Furniture Library Editor\n#\n";
     writer.write(String.format(CATALOG_FILE_HEADER, new Date()));
-    int i = 1;
+    
+    Map<String, DefaultFurnitureCatalog.PropertyKey> localizedProperties = new LinkedHashMap<String, DefaultFurnitureCatalog.PropertyKey>();
+    localizedProperties.put(FurnitureLibrary.FURNITURE_NAME_PROPERTY, DefaultFurnitureCatalog.PropertyKey.NAME);
+    localizedProperties.put(FurnitureLibrary.FURNITURE_DESCRIPTION_PROPERTY, DefaultFurnitureCatalog.PropertyKey.DESCRIPTION);
+    localizedProperties.put(FurnitureLibrary.FURNITURE_INFORMATION_PROPERTY, DefaultFurnitureCatalog.PropertyKey.INFORMATION);
+    localizedProperties.put(FurnitureLibrary.FURNITURE_TAGS_PROPERTY, DefaultFurnitureCatalog.PropertyKey.TAGS);
+    localizedProperties.put(FurnitureLibrary.FURNITURE_CATEGORY_PROPERTY, DefaultFurnitureCatalog.PropertyKey.CATEGORY);
+    
+    int i = 1;    
     for (CatalogPieceOfFurniture piece : furnitureLibrary.getFurniture()) {
       writer.newLine();
-      Object pieceName = furnitureLibrary.getPieceOfFurnitureLocalizedData(
-          piece, language, FurnitureLibrary.FURNITURE_NAME_PROPERTY);
-      if (pieceName != null) {
-        writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.NAME, i, pieceName);
-      }
-      Object pieceDescription = furnitureLibrary.getPieceOfFurnitureLocalizedData(
-          piece, language, FurnitureLibrary.FURNITURE_DESCRIPTION_PROPERTY);
-      if (pieceDescription != null) {
-        writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.DESCRIPTION, i, pieceDescription);
-      }
-      Object categoryName = furnitureLibrary.getPieceOfFurnitureLocalizedData(
-          piece, language, FurnitureLibrary.FURNITURE_CATEGORY_PROPERTY);
-      if (categoryName != null) {
-        writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.CATEGORY, i, categoryName);
+      for (Map.Entry<String, DefaultFurnitureCatalog.PropertyKey> localizedPropertyEntry : localizedProperties.entrySet()) {
+        Object pieceData = furnitureLibrary.getPieceOfFurnitureLocalizedData(
+            piece, language, localizedPropertyEntry.getKey());
+        if (pieceData != null) {
+          writeProperty(writer, localizedPropertyEntry.getValue(), i, pieceData);
+        }
       }
       i++;
     }
@@ -700,7 +711,13 @@ public class FurnitureLibraryFileRecorder implements FurnitureLibraryRecorder {
     if (value != null) {
       writer.write(key);
       writer.write("=");    
-      String s = value.toString();
+      String s;
+      if (value.getClass().isArray()) {
+        s = Arrays.toString((Object [])value);
+        s = s.substring(1, s.length() - 1); // Remove brackets
+      } else {
+        s = value.toString();
+      }
       CharsetEncoder encoder = Charset.forName("ISO-8859-1").newEncoder();
       for (int i = 0; i < s.length(); i++) {
         char c = s.charAt(i);      
